documentationtools.ClassCrawler
===============================

.. inheritance-diagram:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler
   :private-bases:

.. autoclass:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.code_root

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.include_private_objects

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.module_crawler

.. autoattribute:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.root_package_name

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__call__

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.documentationtools.ClassCrawler.ClassCrawler.ClassCrawler.__str__

   .. note:: Inherited from `__builtin__.object`
